Console
#######

You can enter a python shell with the ``console`` command. This will start a python shell with the ``moccasin`` module loaded, so you can interact with your contracts directly.

.. code-block:: bash 

    mox console

Press ``q`` and hit ``ENTER`` to exit the console.